==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecGrpcRouteActionTargetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property port The port number that corresponds to the target for Virtual Service provider port. This is required when the provider (router or node) of the Virtual Service has multiple listeners.
 * @property virtualService Virtual service gateway route target.
 */
public data class GatewayRouteSpecGrpcRouteActionTargetArgs(
    public val port: Output<Int>? = null,
    public val virtualService: Output<GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetArgs.builder()
            .port(port?.applyValue({ args0 -> args0 }))
            .virtualService(
                virtualService.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [GatewayRouteSpecGrpcRouteActionTargetArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecGrpcRouteActionTargetArgsBuilder internal constructor() {
    private var port: Output<Int>? = null

    private var virtualService: Output<GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs>? =
        null

    /**
     * @param value The port number that corresponds to the target for Virtual Service provider port. This is required when the provider (router or node) of the Virtual Service has multiple listeners.
     */
    @JvmName("tmgusypmchduspse")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Virtual service gateway route target.
     */
    @JvmName("ovtawxkxbyprldup")
    public suspend
    fun virtualService(`value`: Output<GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs>) {
        this.virtualService = value
    }

    /**
     * @param value The port number that corresponds to the target for Virtual Service provider port. This is required when the provider (router or node) of the Virtual Service has multiple listeners.
     */
    @JvmName("ijonjyhcykvbbwhl")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Virtual service gateway route target.
     */
    @JvmName("nrxahebprqsdggyp")
    public suspend
    fun virtualService(`value`: GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualService = mapped
    }

    /**
     * @param argument Virtual service gateway route target.
     */
    @JvmName("thpegelcndnijsgh")
    public suspend
    fun virtualService(argument: suspend GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgsBuilder.() -> Unit) {
        val toBeMapped = GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.virtualService = mapped
    }

    internal fun build(): GatewayRouteSpecGrpcRouteActionTargetArgs =
        GatewayRouteSpecGrpcRouteActionTargetArgs(
            port = port,
            virtualService = virtualService ?: throw PulumiNullFieldException("virtualService"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecGrpcRouteActionTargetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property port The port number that corresponds to the target for Virtual Service provider port. This is required when the provider (router or node) of the Virtual Service has multiple listeners.
 * @property virtualService Virtual service gateway route target.
 */
public data class GatewayRouteSpecGrpcRouteActionTargetArgs(
    public val port: Output<Int>? = null,
    public val virtualService: Output<GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetArgs.builder()
            .port(port?.applyValue({ args0 -> args0 }))
            .virtualService(
                virtualService.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [GatewayRouteSpecGrpcRouteActionTargetArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecGrpcRouteActionTargetArgsBuilder internal constructor() {
    private var port: Output<Int>? = null

    private var virtualService: Output<GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs>? =
        null

    /**
     * @param value The port number that corresponds to the target for Virtual Service provider port. This is required when the provider (router or node) of the Virtual Service has multiple listeners.
     */
    @JvmName("pvirhslsfjvfhtlk")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Virtual service gateway route target.
     */
    @JvmName("teqayrybeqptrqgx")
    public suspend fun virtualService(`value`: Output<GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs>) {
        this.virtualService = value
    }

    /**
     * @param value The port number that corresponds to the target for Virtual Service provider port. This is required when the provider (router or node) of the Virtual Service has multiple listeners.
     */
    @JvmName("qyvcenwffvncjbec")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Virtual service gateway route target.
     */
    @JvmName("xporwqrldhhqxngr")
    public suspend fun virtualService(`value`: GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualService = mapped
    }

    /**
     * @param argument Virtual service gateway route target.
     */
    @JvmName("ignhnxvtocxjsahl")
    public suspend fun virtualService(argument: suspend GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgsBuilder.() -> Unit) {
        val toBeMapped = GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.virtualService = mapped
    }

    internal fun build(): GatewayRouteSpecGrpcRouteActionTargetArgs =
        GatewayRouteSpecGrpcRouteActionTargetArgs(
            port = port,
            virtualService = virtualService ?: throw PulumiNullFieldException("virtualService"),
        )
}
